Revert "COMPMID-959: Fix valid region for Scale by always setting full shape"

This reverts commit 77fdc0420dfd3c5009370650f963748a73f0db58.

Change-Id: I1440f56f29637821e20ad2edf1055196bb69a0e2
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/124290
Tested-by: Jenkins <bsgcomp@arm.com>
Reviewed-by: Isabella Gottardi <isabella.gottardi@arm.com>
diff --git a/arm_compute/core/Helpers.h b/arm_compute/core/Helpers.h
index c412d21..24ba521 100644
--- a/arm_compute/core/Helpers.h
+++ b/arm_compute/core/Helpers.h
@@ -620,16 +620,15 @@
 
 /** Helper function to calculate the Valid Region for Scale.
  *
  * @param[in] src_info           Input tensor info used to check.
  * @param[in] dst_shape          Shape of the output.
  * @param[in] interpolate_policy Interpolation policy.
  * @param[in] sampling_policy    Sampling policy.
  * @param[in] border_undefined   True if the border is undefined.
  *
- * @return The corresponding valid region
+ * @return The corrispondent valid region
  */
-ValidRegion calculate_valid_region_scale(const ITensorInfo &src_info, const TensorShape &dst_shape,
-                                         InterpolationPolicy interpolate_policy, SamplingPolicy sampling_policy, bool border_undefined);
+ValidRegion calculate_valid_region_scale(const ITensorInfo &src_info, const TensorShape &dst_shape, InterpolationPolicy policy, BorderSize border_size, bool border_undefined);
 
 /** Convert a linear index into n-dimensional coordinates.
  *
@@ -620,16 +620,15 @@
 /** Helper function to calculate the Valid Region for Scale.
  *
- * @param[in] src_info           Input tensor info used to check.
- * @param[in] dst_shape          Shape of the output.
- * @param[in] interpolate_policy Interpolation policy.
- * @param[in] sampling_policy    Sampling policy.
- * @param[in] border_undefined   True if the border is undefined.
+ * @param[in] src_info         Input tensor info used to check.
+ * @param[in] dst_shape        Shape of the output.
+ * @param[in] policy           Interpolation policy.
+ * @param[in] border_size      Size of the border.
+ * @param[in] border_undefined True if the border is undefined.
  *